@@ -74,6 +74,46 @@ class IPv4Obj(object):
             errmsg = "{0} cannot compare itself to '{1}'".format(self.__repr__(), val)
             raise ValueError(errmsg)
 
+    def __gt__(self, val):
+        try:
+            val_prefixlen = int(getattr(val, 'prefixlen'))
+            val_nobj = getattr(val, 'network_object')
+
+            self_prefixlen = self.network_object.prefixlen
+            self_nobj = self.network_object
+            if (self.network_object.prefixlen<val_prefixlen):
+                # Sort shorter masks as higher...
+                return True
+            elif (self.network_object.prefixlen>val_prefixlen):
+                return False
+            elif (self_nobj>val_nobj):
+                # If masks are equal, rely on Google's sorting...
+                return True
+            return False
+        except:
+            errmsg = "{0} cannot compare itself to '{1}'".format(self.__repr__(), val)
+            raise ValueError(errmsg)
+
+    def __lt__(self, val):
+        try:
+            val_prefixlen = int(getattr(val, 'prefixlen'))
+            val_nobj = getattr(val, 'network_object')
+
+            self_prefixlen = self.network_object.prefixlen
+            self_nobj = self.network_object
+            if (self.network_object.prefixlen>val_prefixlen):
+                # Sort shorter masks as lower...
+                return True
+            elif (self.network_object.prefixlen<val_prefixlen):
+                return False
+            elif (self_nobj<val_nobj):
+                # If masks are equal, rely on Google's sorting...
+                return True
+            return False
+        except:
+            errmsg = "{0} cannot compare itself to '{1}'".format(self.__repr__(), val)
+            raise ValueError(errmsg)
+
     def __hash__(self):
         # Python3 needs __hash__()
         return hash(str(self.ip_object))+hash(str(self.prefixlen))
